@@ -215,7 +215,7 @@ INPUT_RETURN_VALUE FcitxLibPinyinDoInput(void* arg, FcitxKeySym sym, unsigned in
 
                 if (parselen == 0 && strlen(libpinyin->buf) == 1 && libpinyin->type != LPT_Shuangpin
                         && !(libpinyin->type == LPT_Pinyin && !libpinyin->owner->config.incomplete)
-                        && !(libpinyin->type == LPT_Zhuyin && !libpinyin->owner->config.chewingIncomplete)) {
+                        && !(libpinyin->type == LPT_Zhuyin && !libpinyin->owner->config.zhuyinIncomplete)) {
                     FcitxLibPinyinReset(libpinyin);
                     return IRV_TO_PROCESS;
                 }
@@ -354,10 +354,6 @@ void FcitxLibPinyinLoad(FcitxLibPinyin* libpinyin)
         char* user_path = FcitxLibPinyinGetUserPath(libpinyinaddon->config.bSimplifiedDataForZhuyin ? LPLT_Simplified : LPLT_Traditional);
         char* syspath = FcitxLibPinyinGetSysPath(libpinyinaddon->config.bSimplifiedDataForZhuyin ? LPLT_Simplified : LPLT_Traditional);
         libpinyinaddon->zhuyin_context = pinyin_init(syspath, user_path);
-        pinyin_load_phrase_library(libpinyinaddon->zhuyin_context, GBK_DICTIONARY);
-        pinyin_load_phrase_library(libpinyinaddon->zhuyin_context, MERGED_DICTIONARY);
-        pinyin_load_phrase_library(libpinyinaddon->zhuyin_context, 14);
-        pinyin_load_phrase_library(libpinyinaddon->zhuyin_context, USER_DICTIONARY);
         free(user_path);
         free(syspath);
     }
@@ -366,10 +362,6 @@ void FcitxLibPinyinLoad(FcitxLibPinyin* libpinyin)
         char* user_path = FcitxLibPinyinGetUserPath(libpinyinaddon->config.bTraditionalDataForPinyin ? LPLT_Traditional : LPLT_Simplified);
         char* syspath = FcitxLibPinyinGetSysPath(libpinyinaddon->config.bTraditionalDataForPinyin ? LPLT_Traditional : LPLT_Simplified);
         libpinyinaddon->pinyin_context = pinyin_init(syspath, user_path);
-        pinyin_load_phrase_library(libpinyinaddon->pinyin_context, GBK_DICTIONARY);
-        pinyin_load_phrase_library(libpinyinaddon->pinyin_context, MERGED_DICTIONARY);
-        pinyin_load_phrase_library(libpinyinaddon->pinyin_context, 14);
-        pinyin_load_phrase_library(libpinyinaddon->pinyin_context, USER_DICTIONARY);
         free(user_path);
         free(syspath);
     }
@@ -518,7 +510,7 @@ void FcitxLibPinyinUpdatePreedit(FcitxLibPinyin* libpinyin, char* sentence)
             guint16 pykeyposLen = 0;
             pinyin_get_pinyin_key_rest_length(libpinyin->inst, pykeypos, &pykeyposLen);
             gchar* pystring;
-            pinyin_get_chewing_string(libpinyin->inst, pykey, &pystring);
+            pinyin_get_zhuyin_string(libpinyin->inst, pykey, &pystring);
             FcitxMessagesAddMessageAtLast(FcitxInputStateGetPreedit(input), MSG_CODE, "%s", pystring);
 
             if (curoffset + pykeyposLen <= libpinyin->cursor_pos) {
@@ -770,7 +762,7 @@ void* LibPinyinSavePinyinWord(void* arg, FcitxModuleFunctionArg args)
     }
 
     if (ss.str().length() > 0) {
-        import_iterator_t* iter = pinyin_begin_add_phrases(context, 15);
+        import_iterator_t* iter = pinyin_begin_add_phrases(context, USER_DICTIONARY);
         if (iter) {
             char* hz = (char*) args.args[0];
             pinyin_iterator_add_phrase(iter, hz, ss.str().c_str(), -1);
@@ -792,6 +784,7 @@ void* FcitxLibPinyinCreate(FcitxInstance* instance)
 {
     FcitxLibPinyinAddonInstance* libpinyinaddon = (FcitxLibPinyinAddonInstance*) fcitx_utils_malloc0(sizeof(FcitxLibPinyinAddonInstance));
     bindtextdomain("fcitx-libpinyin", LOCALEDIR);
+    bind_textdomain_codeset("fcitx-libpinyin", "UTF-8");
     libpinyinaddon->owner = instance;
     FcitxAddon* addon = FcitxAddonsGetAddonByName(FcitxInstanceGetAddons(instance), "fcitx-libpinyin");
 
@@ -890,13 +883,13 @@ void FcitxLibPinyinReconfigure(FcitxLibPinyinAddonInstance* libpinyinaddon)
     FcitxLibPinyinConfig* config = &libpinyinaddon->config;
 
     if (libpinyinaddon->zhuyin_context) {
-        pinyin_set_chewing_scheme(libpinyinaddon->zhuyin_context, FcitxLibPinyinTransZhuyinLayout(config->zhuyinLayout));
+        pinyin_set_zhuyin_scheme(libpinyinaddon->zhuyin_context, FcitxLibPinyinTransZhuyinLayout(config->zhuyinLayout));
 
-        for (int i = 0; i <= FCITX_DICT_LAST; i++) {
-            if (config->dict[i]) {
-                pinyin_load_phrase_library(libpinyinaddon->zhuyin_context, FcitxLibPinyinTransDictionary(static_cast<FCITX_DICTIONARY>(i)));
+        for (int i = 0; i <= FCITX_ZHUYIN_DICT_LAST; i++) {
+            if (config->dict_zhuyin[i]) {
+                pinyin_load_addon_phrase_library(libpinyinaddon->zhuyin_context, FcitxLibPinyinTransZhuyinDictionary(static_cast<FCITX_ZHUYIN_DICTIONARY>(i)));
             } else {
-                pinyin_unload_phrase_library(libpinyinaddon->zhuyin_context, FcitxLibPinyinTransDictionary(static_cast<FCITX_DICTIONARY>(i)));
+                pinyin_unload_addon_phrase_library(libpinyinaddon->zhuyin_context, FcitxLibPinyinTransZhuyinDictionary(static_cast<FCITX_ZHUYIN_DICTIONARY>(i)));
             }
         }
     }
@@ -904,9 +897,9 @@ void FcitxLibPinyinReconfigure(FcitxLibPinyinAddonInstance* libpinyinaddon)
         pinyin_set_double_pinyin_scheme(libpinyinaddon->pinyin_context, FcitxLibPinyinTransShuangpinScheme(config->spScheme));
         for (int i = 0; i <= FCITX_DICT_LAST; i++) {
             if (config->dict[i]) {
-                pinyin_load_phrase_library(libpinyinaddon->pinyin_context, FcitxLibPinyinTransDictionary(static_cast<FCITX_DICTIONARY>(i)));
+                pinyin_load_addon_phrase_library(libpinyinaddon->pinyin_context, FcitxLibPinyinTransDictionary(static_cast<FCITX_DICTIONARY>(i)));
             } else {
-                pinyin_unload_phrase_library(libpinyinaddon->pinyin_context, FcitxLibPinyinTransDictionary(static_cast<FCITX_DICTIONARY>(i)));
+                pinyin_unload_addon_phrase_library(libpinyinaddon->pinyin_context, FcitxLibPinyinTransDictionary(static_cast<FCITX_DICTIONARY>(i)));
             }
         }
     }
@@ -926,15 +919,15 @@ void FcitxLibPinyinReconfigure(FcitxLibPinyinAddonInstance* libpinyinaddon)
         settings |= PINYIN_INCOMPLETE;
     }
 
-    if (config->chewingIncomplete) {
-        settings |= CHEWING_INCOMPLETE;
+    if (config->zhuyinIncomplete) {
+        settings |= ZHUYIN_INCOMPLETE;
     }
 
     if (config->useTone) {
         settings |= USE_TONE;
     }
     settings |= IS_PINYIN;
-    settings |= IS_CHEWING;
+    settings |= IS_ZHUYIN;
     if (libpinyinaddon->pinyin_context)
         pinyin_set_options(libpinyinaddon->pinyin_context, settings);
     if (libpinyinaddon->zhuyin_context)
@@ -969,10 +962,11 @@ void FcitxLibPinyinClearData(FcitxLibPinyin* libpinyin, int type)
 
     switch (type) {
     case 0:
-        pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(15, null_token));
+        pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(USER_DICTIONARY, null_token));
+        pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(ADDON_DICTIONARY, null_token));
         break;
     case 1:
-        pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(14, null_token));
+        pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(NETWORK_DICTIONARY, null_token));
         break;
     case 2:
         pinyin_mask_out(context, 0, 0);
@@ -999,9 +993,9 @@ void FcitxLibPinyinImport(FcitxLibPinyin* libpinyin)
 
     const char* path = langType == LPLT_Simplified ? "libpinyin/importdict" : "libpinyin/importdict_zhuyin";
 
-    pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(14, null_token));
+    pinyin_mask_out(context, PHRASE_INDEX_LIBRARY_MASK, PHRASE_INDEX_MAKE_TOKEN(NETWORK_DICTIONARY, null_token));
 
-    import_iterator_t* iter = pinyin_begin_add_phrases(context, 14);
+    import_iterator_t* iter = pinyin_begin_add_phrases(context, NETWORK_DICTIONARY);
     if (iter == NULL) {
         return;
     }
